permission.tests.test_templatetags package
==========================================

Submodules
----------

permission.tests.test_templatetags.test_permissionif module
-----------------------------------------------------------

.. automodule:: permission.tests.test_templatetags.test_permissionif
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission.tests.test_templatetags
    :members:
    :undoc-members:
    :show-inheritance:
